.. Daarmaan documentation master file, created by
   sphinx-quickstart on Wed Aug 29 22:02:09 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. sectionauthor:: Sameer Rahmani <lxsameer@gnu.org>

Welcome to Daarmaan's documentation!
=====================================

Daarmaan is Single Sign On (`SSO <http://en.wikipedia.org/wiki/Single_sign-on>`_) service.
Contents:

.. toctree::
   :maxdepth: 2
   :titlesonly:

   Quick start <quickstart.rst>
   Developer Mini Guide <devguide.rst>
   FAQ <faq.rst>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

